==> scummvm_1.9.0+dfsg.orig.tar.xz: scummvm-1.9.0/engines/titanic/npcs/parrot_succubus.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_PARROT_SUCCUBUS_H
#define TITANIC_PARROT_SUCCUBUS_H

#include "titanic/npcs/succubus.h"

namespace Titanic {

class CParrotSuccUBus : public CSuccUBus {
	DECLARE_MESSAGE_MAP;
	bool HoseConnectedMsg(CHoseConnectedMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool MovieEndMsg(CMovieEndMsg *msg);
	bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
	bool LeaveNodeMsg(CLeaveNodeMsg *msg);
public:
	int _field1DC;
	CString _string3;
	int _field1EC;
	int _field1F0;
	int _field1F4;
public:
	CLASSDEF;
	CParrotSuccUBus();

	/**
	 * Save the data for the class to file
	 */
	virtual void save(SimpleFile *file, int indent);

	/**
	 * Load the data for the class from file
	 */
	virtual void load(SimpleFile *file);
};

} // End of namespace Titanic

#endif /* TITANIC_PARROT_SUCCUBUS_H */

==> scummvm_2.0.0+dfsg.orig.tar.xz: scummvm-2.0.0/engines/titanic/npcs/parrot_succubus.h <==
/* ScummVM - Graphic Adventure Engine
 *
 * ScummVM is the legal property of its developers, whose names
 * are too numerous to list here. Please refer to the COPYRIGHT
 * file distributed with this source distribution.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 */

#ifndef TITANIC_PARROT_SUCCUBUS_H
#define TITANIC_PARROT_SUCCUBUS_H

#include "titanic/npcs/succubus.h"

namespace Titanic {

class CParrotSuccUBus : public CSuccUBus {
	DECLARE_MESSAGE_MAP;
	bool HoseConnectedMsg(CHoseConnectedMsg *msg);
	bool EnterViewMsg(CEnterViewMsg *msg);
	bool MovieEndMsg(CMovieEndMsg *msg);
	bool MouseButtonDownMsg(CMouseButtonDownMsg *msg);
	bool LeaveNodeMsg(CLeaveNodeMsg *msg);
public:
	bool _hoseConnected;
	CString _pumpingTarget;
	int _pumpingSound;
	int _hoseRemovalStartFrame;
	int _hoseRemovalEndFrame;
public:
	CLASSDEF;
	CParrotSuccUBus();

	/**
	 * Save the data for the class to file
	 */
	virtual void save(SimpleFile *file, int indent);

	/**
	 * Load the data for the class from file
	 */
	virtual void load(SimpleFile *file);
};

} // End of namespace Titanic

#endif /* TITANIC_PARROT_SUCCUBUS_H */
